@@ -11,7 +11,7 @@ class copyToDialog : public QDialog
 {
     Q_OBJECT
 
-    friend class fourImages;
+    friend class wpNew;
 
 public:
     explicit copyToDialog(QWidget *parent = 0);
