@@ -1,10 +1,17 @@
-#include "wpnew.h"
-#include "ui_wpnew.h"
-#include "wpmanager.h"
-#include "ui_wpmanager.h"
 #include "wallpaeper.h"
 #include "ui_wallpaeper.h"
 
+#include "wpnew.h"
+#include "ui_wpnew.h"
+
+#include "wpmanager.h"
+#include "ui_wpmanager.h"
+
+#include "aboutdialog.h"
+#include "ui_aboutdialog.h"
+
+#include <QMessageBox>
+
 wallPaeper::wallPaeper(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::wallPaeper)
@@ -94,14 +101,10 @@ void wallPaeper::openWinTrue() {
 
 
 void wallPaeper::setupWPMenuBar() {
-    // The main menu
-    wpMenuActionAbout = new QAction(tr("About..."), this);
-
-    wpMenu = menuBar()->addMenu("");
-    wpMenu->addAction(wpMenuActionAbout);
-
-    connect(wpMenuActionAbout, SIGNAL(triggered()),
-            this, SLOT(createAbtDialog()));
+    wpMenuBar = new QMenuBar(this);
+    wpMenuBar->addMenu("");
+    wpMenuBar->addAction(tr("About..."), this, SLOT(createAbtDialog()));
+    wpMenuBar->addAction(tr("About") + " Qt...", this, SLOT(createAbtQtDialog()));
 }
 
 
@@ -121,3 +124,11 @@ void wallPaeper::createAbtDialog() {
     abtDialog->adjustSize();
     abtDialog->show();
 }
+
+
+
+
+
+void wallPaeper::createAbtQtDialog() {
+    QMessageBox::aboutQt(this, "About Qt");
+}
