@@ -1,7 +1,11 @@
 #include "wpmanager.h"
 #include "ui_wpmanager.h"
-#include "wallpaeper.h"
-#include "ui_wallpaeper.h"
+
+#include "wpnew.h"
+#include "ui_wpnew.h"
+
+#include "deletedialog.h"
+#include "ui_deletedialog.h"
 
 #include <QMaemo5InformationBox>
 #include <QMessageBox>
@@ -27,7 +31,7 @@ wpManager::wpManager(QWidget *parent) :
             this, SLOT(updateList()));
 
     openEditWin = true;
-    fileView = filenames;
+    fileView = names; // Default value
     setupWPManMenuBar();
 
     connect(ui->fileList, SIGNAL(itemSelectionChanged()),
@@ -38,7 +42,7 @@ wpManager::wpManager(QWidget *parent) :
     connect(ui->manEditBtn, SIGNAL(clicked()),
             this, SLOT(editCurrent()));
     connect(ui->manInstBtn, SIGNAL(clicked()),
-            this, SLOT(startProcess()));
+            this, SLOT(installSet()));
     connect(ui->manDelBtn, SIGNAL(clicked()),
             this, SLOT(confirmDelSet()));
 
@@ -73,17 +77,10 @@ wpManager::~wpManager()
 
 
 void wpManager::setupWPManMenuBar() {
-    wpManViewNames = new QAction(tr("View names"), this);
-    wpManViewFilenames = new QAction(tr("View filenames"), this);
-
-    wpManMenu = menuBar()->addMenu("");
-    wpManMenu->addAction(wpManViewNames);
-    wpManMenu->addAction(wpManViewFilenames);
-
-    connect(wpManViewNames, SIGNAL(triggered()),
-            this, SLOT(viewNames()));
-    connect(wpManViewFilenames, SIGNAL(triggered()),
-            this, SLOT(viewFilenames()));
+    wpManMenuBar = new QMenuBar(this);
+    wpManMenuBar->addMenu("");
+    wpManMenuBar->addAction(tr("View names"), this, SLOT(viewNames()));
+    wpManMenuBar->addAction(tr("View filenames"), this, SLOT(viewFilenames()));
 }
 
 
@@ -222,8 +219,7 @@ bool wpManager::checkSelected() {
                                            QMaemo5InformationBox::DefaultTimeout);
         return false;
     }
-    else
-        return true;
+    return true;
 }
 
 
@@ -348,6 +344,43 @@ void wpManager::confirmDelSet() {
 
 
 
+void wpManager::installSet() {
+    if(checkSelected() == true) {
+        // Install the current image set
+        for(i=1; i<=4; i++) {
+            system("gconftool -s /apps/osso/hildon-desktop/views/"
+                   + QString::number(i).toAscii()
+                   + "/bg-image -t string "
+                   + imageSetList[ui->fileList->currentRow()][i].toAscii());
+        }
+        QMessageBox::information(this,
+                                 tr("Confirmation"),
+                                 QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName()
+                                 + tr(" installed!") + "<br><br>"
+                                 + tr("Images should now pop up one by one.") + "<br>"
+                                 + tr("This takes a short while.") + "<br>"
+                                 + tr("(Closing") + " Wallpaeper " + tr("now doesn't stop this process)"),
+                                 QMessageBox::Ok);
+    }
+}
+
+
+
+
+
+void wpManager::itemChanged() {
+    // Clear previews to avoid confusion
+    for(i=0; i<4; i++)
+        manPrev[i]->setPixmap(QPixmap(""));
+    ui->manPrevName->setText("");
+    if(ui->fileList->currentItem()->isSelected() == false)
+        ui->fileList->currentItem()->setSelected(true);
+}
+
+
+
+
+
 void wpManager::delSet() {
     // If the file is removed, show confirmation
     if(delFileWithPath.remove()) {
@@ -373,111 +406,6 @@ void wpManager::delSet() {
 
 
 
-void wpManager::startProcess() {
-    if(checkSelected() == true) {
-        getNumViews.close();
-
-        connect(&getNumViews, SIGNAL(readyReadStandardOutput()),
-                this, SLOT(readProcess()));
-
-        // Start the process
-        getNumViews.start("gconftool-2 -R /apps/osso/hildon-desktop/views", QProcess::ReadOnly);
-    }
-}
-
-
-
-
-
-void wpManager::readProcess() {
-    // Append all output to outData
-    outData.append(getNumViews.readAllStandardOutput());
-
-    // Read number of active views (desktops)
-    if(outData.contains("active = [1]")) {
-        numViews = 1;
-        installSet();
-    }
-    if(outData.contains("active = [1,2]")) {
-        numViews = 2;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3]")) {
-        numViews = 3;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3,4]")) {
-        numViews = 4;
-        installSet();
-    }
-    /*
-    if(outData.contains("active = [1,2,3,4,5]")) {
-        numViews = 5;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3,4,5,6]")) {
-        numViews = 6;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3,4,5,6,7]")) {
-        numViews = 7;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3,4,5,6,7,8]")) {
-        numViews = 8;
-        installSet();
-    }
-    if(outData.contains("active = [1,2,3,4,5,6,7,8,9]")) {
-        numViews = 9;
-        installSet();
-    }
-    */
-}
-
-
-
-
-
-void wpManager::installSet() {
-    // Disconnect and stop the process
-    disconnect(&getNumViews, SIGNAL(readyReadStandardOutput()),
-            this, SLOT(readProcess()));
-    getNumViews.close();
-
-    // Install the current image set
-    for(i=1; i<=numViews; i++) {
-        system("gconftool -s /apps/osso/hildon-desktop/views/"
-               + QString::number(i).toAscii()
-               + "/bg-image -t string "
-               + imageSetList[ui->fileList->currentRow()][i].toAscii());
-    }
-    QMessageBox::information(this,
-                             tr("Confirmation"),
-                             QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName()
-                             + tr(" installed!") + "<br><br>"
-                             + tr("They should now pop up one by one.") + "<br>"
-                             + tr("This takes a short while.") + "<br>"
-                             + tr("(Closing") + " Wallpaeper " + tr("now doesn't stop this process)"),
-                             QMessageBox::Ok);
-}
-
-
-
-
-
-void wpManager::itemChanged() {
-    // Clear previews to avoid confusion
-    for(i=0; i<4; i++)
-        manPrev[i]->setPixmap(QPixmap(""));
-    ui->manPrevName->setText("");
-    if(ui->fileList->currentItem()->isSelected() == false)
-        ui->fileList->currentItem()->setSelected(true);
-}
-
-
-
-
-
 void wpManager::reselectAfterEdit() {
     // Reselect the row that was selected before editing
     ui->fileList->setCurrentRow(curRowBeforeEdit);
