@@ -1,18 +1,17 @@
 #ifndef WPMANAGER_H
 #define WPMANAGER_H
 
-#include "wpnew.h"
-#include "ui_wpnew.h"
-#include "deletedialog.h"
-#include "ui_deletedialog.h"
-
 #include <QMainWindow>
 #include <QDir>
 #include <QLabel>
 #include <QPushButton>
 #include <QListWidgetItem>
 #include <QFileSystemWatcher>
-#include <QProcess>
+#include <QMenu>
+#include <QMenuBar>
+
+class deleteDialog;
+class wpNew;
 
 namespace Ui {
     class wpManager;
@@ -32,10 +31,9 @@ public slots:
 
     void updatePrevs();
     void editCurrent();
+    void installSet();
     void confirmDelSet();
     void delSet();
-    void startProcess();
-    void readProcess();
 
     void itemChanged();
     void updateList();
@@ -50,8 +48,6 @@ private:
     bool checkSelected();
     void fillImageSetList();
     void changeView();
-    void gconfTest();
-    void installSet(); // also stops process
 
     /************ VARIABLES **************/
     int i;
@@ -89,9 +85,7 @@ private:
     int curRowBeforeEdit;
 
     // The view-menu
-    QMenu* wpManMenu;
-    QAction* wpManViewNames;
-    QAction* wpManViewFilenames;
+    QMenuBar* wpManMenuBar;
 
     enum listView {
         names,
@@ -100,10 +94,6 @@ private:
 
     QFileSystemWatcher watchDir;
     bool openEditWin;
-
-    QProcess getNumViews;
-    QString outData;
-    int numViews;
 };
 
 #endif // WPMANAGER_H
